==> v21.04.tar.gz: bookstack/resources/lang/pt_BR/common.php <==
<?php
/**
 * Common elements found throughout many areas of BookStack.
 */
return [

    // Buttons
    'cancel' => 'Cancelar',
    'confirm' => 'Confirmar',
    'back' => 'Voltar',
    'save' => 'Salvar',
    'continue' => 'Continuar',
    'select' => 'Selecionar',
    'toggle_all' => 'Alternar Todos',
    'more' => 'Mais',

    // Form Labels
    'name' => 'Nome',
    'description' => 'Descrição',
    'role' => 'Cargo',
    'cover_image' => 'Imagem de capa',
    'cover_image_description' => 'Esta imagem deve ser aproximadamente 440x250px.',
    
    // Actions
    'actions' => 'Ações',
    'view' => 'Visualizar',
    'view_all' => 'Visualizar Tudo',
    'create' => 'Criar',
    'update' => 'Atualizar',
    'edit' => 'Editar',
    'sort' => 'Ordenar',
    'move' => 'Mover',
    'copy' => 'Copiar',
    'reply' => 'Responder',
    'delete' => 'Excluir',
    'delete_confirm' => 'Confirmar Exclusão',
    'search' => 'Pesquisar',
    'search_clear' => 'Limpar Pesquisa',
    'reset' => 'Redefinir',
    'remove' => 'Remover',
    'add' => 'Adicionar',
    'fullscreen' => 'Tela cheia',

    // Sort Options
    'sort_options' => 'Opções de Ordenação',
    'sort_direction_toggle' => 'Alternar Direção de Ordenação',
    'sort_ascending' => 'Ordenação Crescente',
    'sort_descending' => 'Ordenação Decrescente',
    'sort_name' => 'Nome',
    'sort_default' => 'Default',
    'sort_created_at' => 'Data de Criação',
    'sort_updated_at' => 'Data de Atualização',

    // Misc
    'deleted_user' => 'Usuário excluído',
    'no_activity' => 'Nenhuma atividade a mostrar',
    'no_items' => 'Nenhum item disponível',
    'back_to_top' => 'Voltar ao topo',
    'toggle_details' => 'Alternar Detalhes',
    'toggle_thumbnails' => 'Alternar Miniaturas',
    'details' => 'Detalhes',
    'grid_view' => 'Visualização em Grade',
    'list_view' => 'Visualização em Lista',
    'default' => 'Padrão',
    'breadcrumb' => 'Caminho',

    // Header
    'profile_menu' => 'Menu de Perfil',
    'view_profile' => 'Visualizar Perfil',
    'edit_profile' => 'Editar Perfil',
    'dark_mode' => 'Modo Escuro',
    'light_mode' => 'Modo Claro',

    // Layout tabs
    'tab_info' => 'Informações',
    'tab_content' => 'Conteúdo',

    // Email Content
    'email_action_help' => 'Se você estiver tendo problemas ao clicar o botão ":actionText", copie e cole a URL abaixo no seu navegador:',
    'email_rights' => 'Todos os direitos reservados',

    // Footer Link Options
    // Not directly used but available for convenience to users.
    'privacy_policy' => 'Políticas de Privacidade',
    'terms_of_service' => 'Termos de Serviço',
];

==> v21.05.tar.gz: bookstack/resources/lang/pt_BR/common.php <==
<?php
/**
 * Common elements found throughout many areas of BookStack.
 */
return [

    // Buttons
    'cancel' => 'Cancelar',
    'confirm' => 'Confirmar',
    'back' => 'Voltar',
    'save' => 'Salvar',
    'continue' => 'Continuar',
    'select' => 'Selecionar',
    'toggle_all' => 'Alternar Todos',
    'more' => 'Mais',

    // Form Labels
    'name' => 'Nome',
    'description' => 'Descrição',
    'role' => 'Cargo',
    'cover_image' => 'Imagem de capa',
    'cover_image_description' => 'Esta imagem deve ser aproximadamente 440x250px.',
    
    // Actions
    'actions' => 'Ações',
    'view' => 'Visualizar',
    'view_all' => 'Visualizar Tudo',
    'create' => 'Criar',
    'update' => 'Atualizar',
    'edit' => 'Editar',
    'sort' => 'Ordenar',
    'move' => 'Mover',
    'copy' => 'Copiar',
    'reply' => 'Responder',
    'delete' => 'Excluir',
    'delete_confirm' => 'Confirmar Exclusão',
    'search' => 'Pesquisar',
    'search_clear' => 'Limpar Pesquisa',
    'reset' => 'Redefinir',
    'remove' => 'Remover',
    'add' => 'Adicionar',
    'fullscreen' => 'Tela cheia',
    'favourite' => 'Favourite',
    'unfavourite' => 'Unfavourite',
    'next' => 'Next',
    'previous' => 'Previous',

    // Sort Options
    'sort_options' => 'Opções de Ordenação',
    'sort_direction_toggle' => 'Alternar Direção de Ordenação',
    'sort_ascending' => 'Ordenação Crescente',
    'sort_descending' => 'Ordenação Decrescente',
    'sort_name' => 'Nome',
    'sort_default' => 'Padrão',
    'sort_created_at' => 'Data de Criação',
    'sort_updated_at' => 'Data de Atualização',

    // Misc
    'deleted_user' => 'Usuário excluído',
    'no_activity' => 'Nenhuma atividade a mostrar',
    'no_items' => 'Nenhum item disponível',
    'back_to_top' => 'Voltar ao topo',
    'toggle_details' => 'Alternar Detalhes',
    'toggle_thumbnails' => 'Alternar Miniaturas',
    'details' => 'Detalhes',
    'grid_view' => 'Visualização em Grade',
    'list_view' => 'Visualização em Lista',
    'default' => 'Padrão',
    'breadcrumb' => 'Caminho',

    // Header
    'header_menu_expand' => 'Expand Header Menu',
    'profile_menu' => 'Menu de Perfil',
    'view_profile' => 'Visualizar Perfil',
    'edit_profile' => 'Editar Perfil',
    'dark_mode' => 'Modo Escuro',
    'light_mode' => 'Modo Claro',

    // Layout tabs
    'tab_info' => 'Informações',
    'tab_info_label' => 'Tab: Show Secondary Information',
    'tab_content' => 'Conteúdo',
    'tab_content_label' => 'Tab: Show Primary Content',

    // Email Content
    'email_action_help' => 'Se você estiver tendo problemas ao clicar o botão ":actionText", copie e cole a URL abaixo no seu navegador:',
    'email_rights' => 'Todos os direitos reservados',

    // Footer Link Options
    // Not directly used but available for convenience to users.
    'privacy_policy' => 'Políticas de Privacidade',
    'terms_of_service' => 'Termos de Serviço',
];
